#Module-Specific definitions
%define mod_name mod_wsgi

Summary:        Python WSGI adapter module for Apache
Name:           apache-%{mod_name}
Version:        4.4.22
Release:        %mkrel 1
Group:          System/Servers
License:        Apache License
URL:            https://github.com/GrahamDumpleton/mod_wsgi
# Download from GitHub:
# https://github.com/GrahamDumpleton/mod_wsgi/releases
Source0:        https://github.com/GrahamDumpleton/mod_wsgi/archive/%{version}.tar.gz
Source1:        mod_wsgi.conf
Source2:        wsgi.conf
Source3:        mod_wsgi-python3.conf
Patch0:         mod_wsgi-3.4-configure-python3.patch
Patch1:         mod_wsgi-link-apr.diff
Requires:       apache
BuildRequires:  apache-devel
BuildRequires:  python-devel
BuildRequires:  python-setuptools
BuildRequires:  apr-devel
BuildRequires:  libtool

%description
The mod_wsgi adapter is an Apache module that provides a WSGI compliant
interface for hosting Python based web applications within Apache. The
adapter is written completely in C code against the Apache C runtime and
for hosting WSGI applications within Apache has a lower overhead than using
existing WSGI adapters for mod_python or CGI.

%package -n apache-python3-%{mod_name}
Summary:        Python3 WSGI adapter module for Apache
Group:          System/Servers
Requires:       apache
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools

%description -n apache-python3-%{mod_name}
The mod_wsgi adapter is an Apache module that provides a WSGI compliant
interface for hosting Python3 based web applications within Apache. The
adapter is written completely in C code against the Apache C runtime and
for hosting WSGI applications within Apache has a lower overhead than using
existing WSGI adapters for mod_python or CGI.

%prep
%setup -q -n %{mod_name}-%{version}
%patch1 -p0

cp -a . %{py3dir}
pushd %{py3dir}
%patch0 -p1
popd

%build

%{__python2} setup.py build
pushd %{py3dir}
export LDFLAGS="$RPM_LD_FLAGS -L%{_libdir}"
export CFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing"

%{__python3} setup.py build
popd

%install

mkdir -p %{buildroot}%{_httpd_moddir}
pushd %{py3dir}
# %%{__python3} setup.py install --root=%%{buildroot} --skip-build
mv $(find build -name '*.so') %{buildroot}%{_httpd_moddir}/mod_wsgi_python3.so
install -D -m 644 %{SOURCE3} %{buildroot}%{_httpd_modconfdir}/10_mod_wsgi_python3.conf
popd

# %%{__python2} setup.py install --root=%%{buildroot} --skip-build
mv $(find build -name '*.so') %{buildroot}%{_httpd_moddir}/mod_wsgi.so
install -D -m 644 %{SOURCE1} %{buildroot}%{_httpd_modconfdir}/10_mod_wsgi.conf
install -D -m 644 %{SOURCE2} %{buildroot}%{_httpd_extconfdir}/wsgi.conf


%files
%doc LICENSE README*
%config(noreplace) %{_httpd_modconfdir}/10_mod_wsgi.conf
%config(noreplace) %{_httpd_extconfdir}/wsgi.conf
%{_httpd_moddir}/mod_wsgi.so

%files -n apache-python3-%{mod_name}
%doc LICENSE README*
%config(noreplace) %{_httpd_modconfdir}/10_mod_wsgi_python3.conf
%{_httpd_moddir}/mod_wsgi_python3.so


%changelog
* Thu Feb 11 2016 shlomif <shlomif> 4.4.22-1.mga6
+ Revision: 953713
- New version + fix build

  + luigiwalser <luigiwalser>
    - add patch to fix linking with libapr

  + umeabot <umeabot>
    - Mageia 6 Mass Rebuild

* Thu Oct 08 2015 daviddavid <daviddavid> 4.2.6-5.mga6
+ Revision: 887249
- rebuild for python 3.5

* Wed Oct 15 2014 umeabot <umeabot> 4.2.6-4.mga5
+ Revision: 748965
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 4.2.6-3.mga5
+ Revision: 725946
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 4.2.6-2.mga5
+ Revision: 677848
- Mageia 5 Mass Rebuild

* Fri Aug 01 2014 oden <oden> 4.2.6-1.mga5
+ Revision: 658866
- da capo
- added any README file
- 4.2.6
- 4.2.4

* Wed Jun 04 2014 fwang <fwang> 3.5-2.mga5
+ Revision: 632833
- rebuild for new python3

* Wed May 21 2014 shlomif <shlomif> 3.5-1.mga5
+ Revision: 624727
- New version 3.5

* Wed Apr 16 2014 philippem <philippem> 3.4-4.mga5
+ Revision: 615301
- add python3

* Fri Oct 18 2013 umeabot <umeabot> 3.4-3.mga4
+ Revision: 502542
- Mageia 4 Mass Rebuild

* Fri Jan 11 2013 umeabot <umeabot> 3.4-2.mga3
+ Revision: 345874
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Dec 24 2012 oden <oden> 3.4-1.mga3
+ Revision: 334677
- 3.4

* Sun Aug 12 2012 guillomovitch <guillomovitch> 3.3-7.mga3
+ Revision: 280787
- fix build with apache 2.4
- adapt to new apache setup

* Mon Mar 19 2012 luigiwalser <luigiwalser> 3.3-6.mga2
+ Revision: 223851
- httpd restart is handled by filetriggers now

* Fri Mar 16 2012 anssi <anssi> 3.3-5.mga2
+ Revision: 223593
- drop ifdefine conditional in configuration as per changes in
  apache init handling

* Sun Sep 18 2011 dmorgan <dmorgan> 3.3-4.mga2
+ Revision: 144686
- Fix buildrequires
- Change apache-conf require

* Fri Feb 04 2011 ahmad <ahmad> 3.3-3.mga1
+ Revision: 46788
- imported package apache-mod_wsgi

